require './raster2eps'
require 'numru/ggraph'
include NumRu


if( ARGV.length < 2 )
  puts( "usage: ruby sat_hdfe.rb hf.YYYYMMDDHH.jpg output.ps" )
  exit
end

# filenames
fname_jpg = ARGV[0]
fname_ps  = ARGV[1]
time      = Time.strptime( File.basename( fname_jpg ), "hf.%Y%m%d%H.jpg" )
time_utc  = time.dup.gmtime
fname_nc  = time_utc.strftime( "MERRA300.prod.assim.inst3_3d_asm_Cp.%Y%m%d.SUB.nc" )
gphys     = File.exist?( fname_nc ) && GPhys::IO.open( fname_nc, "slp" ).cut( "time"=>time_utc.hour )

# (download JPEG)
unless( File.exist?( fname_jpg ) )
  url = time.strftime( "http://weather.is.kochi-u.ac.jp/sat/hdfe/%Y/%m/%d/hf.%Y%m%d%H.jpg" )
  `wget -nc -nv -O #{fname_jpg} #{url}`
  exit unless( File.exist?( fname_jpg ) )
end

puts( <<-EOS )
JPEG: #{fname_jpg}
time: #{time_utc}
data: #{fname_nc}
#{gphys.inspect}
output: #{fname_ps}
EOS


# make dcl.ps
width  = 1920
height = 1080
scale = 1.0 / 3
dx = width  * scale / 734.2
dy = height * scale / 734.2

DCL.gropn( 2 )
DCLExt.sg_set_params( 'lfull'=>true, 'lclip'=>true, 'lcntl'=>false )
DCLExt.ud_set_params( 'icycle'=>5, 'lmsg'=>false )
DCLExt.um_set_params( 'lgridmj'=>false, 'dgridmn'=> 10.0 )

DCL.sgfrm
DCL.sgsvpt( (1.0-dx)/2, (1.0+dx)/2, (0.722-dy)/2, (0.722+dy)/2 )
DCL.sgssim( 1708.0/height*dy/Math.sqrt(4.0/3), 
            (1151.0/width-0.5)*dx, (1055.0/height+0.5)*dy )
DCL.sgsmpl( 135.0, 90.0, 0.0 )
DCL.sgstrn( 31 )
DCL.sgstrf

GGraph.contour( gphys/100.0, false, 'int'=>4.0 ) if( gphys )
GGraph.map( 'grid'=>true, 'vpt'=>true, 'coast_world'=>true )

DCL.grcls


# edit dcl.ps
fp_psin  = File.open( "dcl.ps", "r" )
fp_psout = File.open( fname_ps, "w" )

while( line = fp_psin.gets )
  if( line =~ /^%%BeginObject/ )
    case( line )
    when( /background/ )
      # remove background
      while( line = fp_psin.gets )
        break if( line =~ /^%%EndObject/ )
      end
      next   # reread
    when( /grph1/ )
      # insert JPEG
      w10 = ( width  * scale ).to_i * 10
      h10 = ( height * scale ).to_i * 10
      image = Raster2eps.new( fname_jpg )
      image.trans = [ (7500-w10)/2, (5300-h10)/2 ]
      image.scale = [ w10, h10 ]
      fp_psout.puts( image.convert )
    end
  end
  fp_psout.puts( line )
end

fp_psin. close
fp_psout.close
